# Contributing Guidelines

Thank you for considering contributing to HBAT project!

This is a open-source project, so it's people like you that make it useful and
successful. These are some of the many ways to contribute:

* Submitting bug reports and feature requests
* Writing tutorials or examples
* Fixing typos and improving the documentation
* Writing code for new features

If you get stuck at any point you can create an
[issue](https://github.com/abhishektiwari/hbat/issues) on GitHub.

For more information on contributing to open source projects,
[GitHub's own guide](https://opensource.guide/how-to-contribute)
is a great starting point if you are new to version control. Also, checkout the
[Zen of Scientific Software Maintenance](https://jrleeman.github.io/ScientificSoftwareMaintenance/)
for some guiding principles on how to create high quality scientific software
contributions.


## Ground Rules

The goal is to maintain a diverse community that's pleasant for everyone.
Please be considerate and respectful of others. Everyone must abide by our
[Code of Conduct](/CODE_OF_CONDUCT.md)
and we encourage all to read it carefully.